@@ -377,30 +377,68 @@ namespace Ogre {
 
             
     };
-    /** @} */
-    /** @} */
 
     /** Locking helper. Guaranteed unlocking even in case of exception. */
-    template <typename T> struct HardwareBufferLockGuard
+    struct HardwareBufferLockGuard
     {
-        HardwareBufferLockGuard(const T& p, HardwareBuffer::LockOptions options)
-            : pBuf(p)
+        HardwareBufferLockGuard() : pBuf(0), pData(0) {}
+        
+        HardwareBufferLockGuard(HardwareBuffer* p, HardwareBuffer::LockOptions options)
+            : pBuf(0), pData(0) { lock(p, options); }
+        
+        HardwareBufferLockGuard(HardwareBuffer* p, size_t offset, size_t length, HardwareBuffer::LockOptions options)
+            : pBuf(0), pData(0) { lock(p, offset, length, options); }
+        
+        template <typename T>
+        HardwareBufferLockGuard(const SharedPtr<T>& p, HardwareBuffer::LockOptions options)
+            : pBuf(0), pData(0) { lock(p.get(), options); }
+        
+        template <typename T>
+        HardwareBufferLockGuard(const SharedPtr<T>& p, size_t offset, size_t length, HardwareBuffer::LockOptions options)
+            : pBuf(0), pData(0) { lock(p.get(), offset, length, options); }
+        
+        ~HardwareBufferLockGuard() { unlock(); }
+        
+        void unlock()
         {
+            if(pBuf)
+            {
+                pBuf->unlock();
+                pBuf = 0;
+                pData = 0;
+            }   
+        }
+
+        void lock(HardwareBuffer* p, HardwareBuffer::LockOptions options)
+        {
+            assert(p);
+            unlock();
+            pBuf = p;
             pData = pBuf->lock(options);
         }
-        HardwareBufferLockGuard(const T& p, size_t offset, size_t length, HardwareBuffer::LockOptions options)
-            : pBuf(p)
+        
+        void lock(HardwareBuffer* p, size_t offset, size_t length, HardwareBuffer::LockOptions options)
         {
+            assert(p);
+            unlock();
+            pBuf = p;
             pData = pBuf->lock(offset, length, options);
-        }       
-        ~HardwareBufferLockGuard()
-        {
-            pBuf->unlock();
         }
         
-        const T& pBuf;
+        template <typename T>
+        void lock(const SharedPtr<T>& p, HardwareBuffer::LockOptions options)
+            { lock(p.get(), options); }
+        
+        template <typename T>
+        void lock(const SharedPtr<T>& p, size_t offset, size_t length, HardwareBuffer::LockOptions options)
+            { lock(p.get(), offset, length, options); }
+        
+        HardwareBuffer* pBuf;
         void* pData;
     };
+
+    /** @} */
+    /** @} */
 }
 #endif
 
