@@ -45,6 +45,7 @@ namespace Ogre
     */
 
     class AndroidLogListener;
+    class ShadowTextureManager;
 
     typedef std::vector<RenderSystem*> RenderSystemList;
     
@@ -154,10 +155,8 @@ namespace Ogre
             plugins.
             @param
                 pluginsfile The file that contains plugins information.
-                Defaults to "plugins.cfg" in release and to "plugins_d.cfg"
-                in debug build.
         */
-        void loadPlugins(const String& pluginsfile = "plugins" OGRE_BUILD_SUFFIX ".cfg");
+        void loadPlugins(const String& pluginsfile = "plugins.cfg");
         /** Initialise all loaded plugins - allows plugins to perform actions
             once the renderer is initialised.
         */
@@ -208,14 +207,13 @@ namespace Ogre
 
         /** Constructor
         @param pluginFileName The file that contains plugins information.
-            Defaults to "plugins.cfg" in release build and to "plugins_d.cfg"
-            in debug build. May be left blank to ignore.
+            May be left blank to ignore.
         @param configFileName The file that contains the configuration to be loaded.
             Defaults to "ogre.cfg", may be left blank to load nothing.
         @param logFileName The logfile to create, defaults to Ogre.log, may be 
             left blank if you've already set up LogManager & Log yourself
         */
-        Root(const String& pluginFileName = "plugins" OGRE_BUILD_SUFFIX ".cfg", 
+        Root(const String& pluginFileName = "plugins.cfg",
             const String& configFileName = "ogre.cfg", 
             const String& logFileName = "Ogre.log");
         ~Root();
@@ -583,6 +581,13 @@ namespace Ogre
         RenderWindow* createRenderWindow(const String &name, unsigned int width, unsigned int height, 
             bool fullScreen, const NameValuePairList *miscParams = 0) ;
 
+        /// @overload
+        RenderWindow* createRenderWindow(const RenderWindowDescription& desc)
+        {
+            return createRenderWindow(desc.name, desc.width, desc.height,
+                                      desc.useFullScreen, &desc.miscParams);
+        }
+
         /** @copydoc RenderSystem::_createRenderWindows
         */
         bool createRenderWindows(const RenderWindowDescriptionList& renderWindowDescriptions,
