@@ -43,7 +43,7 @@ namespace RTShader {
 *  @{
 */
 
-#define SGX_LIB_NORMALMAPLIGHTING                   "SGXLib_NormalMapLighting"
+#define SGX_LIB_NORMALMAP                           "SGXLib_NormalMap"
 #define SGX_FUNC_CONSTRUCT_TBNMATRIX                "SGX_ConstructTBNMatrix"
 #define SGX_FUNC_FETCHNORMAL                        "SGX_FetchNormal"
 
@@ -66,7 +66,7 @@ public:
     /** 
     @see SubRenderState::updateGpuProgramsParams.
     */
-    virtual void updateGpuProgramsParams(Renderable* rend, Pass* pass, const AutoParamDataSource* source, const LightList* pLightList);
+    virtual void updateGpuProgramsParams(Renderable* rend, const Pass* pass, const AutoParamDataSource* source, const LightList* pLightList);
 
     /** 
     @see SubRenderState::copyFrom.
@@ -135,22 +135,12 @@ public:
     void setNormalMapFiltering(const FilterOptions minFilter, const FilterOptions magFilter, const FilterOptions mipFilter) 
     { mNormalMapSampler->setFiltering(minFilter, magFilter, mipFilter); }
 
-    /// @deprecated use getNormalMapSampler
-    OGRE_DEPRECATED void getNormalMapFiltering(FilterOptions& minFilter, FilterOptions& magFilter, FilterOptions& mipFilter) const
-    { minFilter = mNormalMapSampler->getFiltering(FT_MIN); magFilter = mNormalMapSampler->getFiltering(FT_MAG) ; mipFilter = mNormalMapSampler->getFiltering(FT_MIP); }
-
     /// @deprecated use setNormalMapSampler
     void setNormalMapAnisotropy(unsigned int anisotropy) { mNormalMapSampler->setAnisotropy(anisotropy); }
 
-    /// @deprecated use getNormalMapSampler
-    OGRE_DEPRECATED unsigned int getNormalMapAnisotropy() const { return mNormalMapSampler->getAnisotropy(); }
-
     /// @deprecated use setNormalMapSampler
     void setNormalMapMipBias(Real mipBias) { mNormalMapSampler->setMipmapBias(mipBias); }
 
-    /// @deprecated use getNormalMapSampler
-    OGRE_DEPRECATED Real getNormalMapMipBias() const { return mNormalMapSampler->getMipmapBias(); }
-
     /// return the normal map sampler
     const SamplerPtr& getNormalMapSampler() const { return mNormalMapSampler; }
 
@@ -178,22 +168,12 @@ protected:
     /** 
     Internal method that adds related vertex shader functions invocations.
     */
-    bool addVSInvocation(Function* vsMain, const int groupOrder);
+    void addVSInvocation(const FunctionStageRef& stage);
 
     /** 
     Internal method that adds per light illumination component functions invocations.
     */
-    bool addVSIlluminationInvocation(LightParams* curLightParams, Function* vsMain, const int groupOrder);
-
-    /** 
-    Internal method that perform normal fetch invocation.
-    */
-    bool addPSNormalFetchInvocation(Function* psMain, const int groupOrder);
-
-    /** 
-    Internal method that adds per light illumination component functions invocations.
-    */
-    bool addPSIlluminationInvocation(LightParams* curLightParams, Function* psMain, const int groupOrder);
+    void addVSIlluminationInvocation(const LightParams* curLightParams, const FunctionStageRef& stage);
 
 // Attributes.
 protected:  
@@ -215,10 +195,6 @@ protected:
     UniformParameterPtr mCamPosWorldSpace;
     // Vertex shader world position parameter.
     ParameterPtr mVSWorldPosition;
-    // Vertex shader output view vector (position in camera space) parameter.
-    ParameterPtr mVSOutView;
-    // Pixel shader input view position (position in camera space) parameter.
-    ParameterPtr mPSInView;
     // Vertex shader input tangent.
     ParameterPtr mVSInTangent;
     // Vertex shader local TNB matrix.
@@ -227,8 +203,6 @@ protected:
     ParameterPtr mVSLocalDir;
     // Normal map texture sampler parameter.
     UniformParameterPtr mPSNormalMapSampler;
-    // Pixel shader normal parameter.
-    ParameterPtr mPSNormal;
     // Vertex shader input texture coordinates.
     ParameterPtr mVSInTexcoord;
     // Vertex shader output texture coordinates.
