@@ -78,17 +78,10 @@ public:
     /// @copydoc Singleton::getSingleton()
     static ProgramManager* getSingletonPtr();
 
-    /** Acquire CPU/GPU programs set associated with the given render state and bind them to the pass.
-    @param pass The pass to bind the programs to.
-    @param renderState The render state that describes the program that need to be generated.
+    /** Release CPU/GPU programs set associated with the given ProgramSet
+    @param renderState The ProgramSet holds the programs.
     */
-    void acquirePrograms(Pass* pass, TargetRenderState* renderState);
-
-    /** Release CPU/GPU programs set associated with the given render state and pass.
-    @param pass The pass to release the programs from.
-    @param renderState The render state holds the programs.
-    */
-    void releasePrograms(Pass* pass, TargetRenderState* renderState);
+    void releasePrograms(const ProgramSet* programSet);
 
     /** Flush the local GPU programs cache.
     */
@@ -144,7 +137,7 @@ protected:
     /** Create GPU programs for the given program set based on the CPU programs it contains.
     @param programSet The program set container.
     */
-    bool createGpuPrograms(ProgramSet* programSet);
+    void createGpuPrograms(ProgramSet* programSet);
         
     /** 
     Generates a unique hash from a string
@@ -197,16 +190,7 @@ protected:
     /** Fix the input of the pixel shader to be the same as the output of the vertex shader */
     void synchronizePixelnToBeVertexOut(ProgramSet* programSet);
 
-    /** Bind the uniform parameters of a given CPU and GPU program set. */
-    void bindUniformParameters(Program* pCpuProgram, const GpuProgramParametersSharedPtr& passParams);
-
-
 protected:
-    
-
-protected:
-    // CPU programs list.                   
-    ProgramList mCpuProgramsList;
     // Map between target language and shader program writer.                   
     ProgramWriterMap mProgramWritersMap;
     // Map between target language and shader program processor.    
