@@ -60,12 +60,6 @@ namespace Ogre {
         /// Rendering loop control
         bool mStopRendering;
 
-        /** Array of up to 8 lights, indexed as per API
-            Note that a null value indicates a free slot
-          */ 
-        #define MAX_LIGHTS 8
-        Light* mLights[MAX_LIGHTS];
-
         /// View matrix to set world against
         Matrix4 mViewMatrix;
         Matrix4 mWorldMatrix;
@@ -84,15 +78,13 @@ namespace Ogre {
         /// Number of fixed-function texture units
         unsigned short mFixedFunctionTextureUnits;
 
-        void setGLLight(size_t index, Light* lt);
+        void setGLLight(size_t index, bool lt);
         void makeGLMatrix(GLfloat gl_matrix[16], const Matrix4& m);
  
         GLint getBlendMode(SceneBlendFactor ogreBlend) const;
         GLint getTextureAddressingMode(TextureAddressingMode tam) const;
                 void initialiseContext(RenderWindow* primary);
 
-        void setLights();
-
         /// Store last colour write state
         bool mColourWrite[4];
         /// Store last stencil mask state
@@ -108,9 +100,6 @@ namespace Ogre {
         GLint convertCompareFunction(CompareFunction func) const;
         GLint convertStencilOp(StencilOperation op, bool invert = false) const;
 
-        /// Internal method to set pos / direction of a light
-        void setGLLightPositionDirection(Light* lt, GLenum lightindex);
-
         bool mUseAutoTextureMatrix;
         GLfloat mAutoTextureMatrix[16];
 
@@ -134,13 +123,6 @@ namespace Ogre {
         // statecaches are per context
         GLStateCacheManager* mStateCacheManager;
 
-        /** Manager object for creating render textures.
-            Direct render to texture via GL_EXT_framebuffer_object is preferable 
-            to pbuffers, which depend on the GL support used and are generally 
-            unwieldy and slow. However, FBO support for stencil buffers is poor.
-        */
-        GLRTTManager *mRTTManager;
-
         ushort mActiveTextureUnit;
         ushort mMaxBuiltInTextureAttribIndex;
 
@@ -173,9 +155,13 @@ namespace Ogre {
         // Overridden RenderSystem functions
         // ----------------------------------
 
+        const GpuProgramParametersPtr& getFixedFunctionParams(TrackVertexColourType tracking, FogMode fog);
+
+        void applyFixedFunctionParams(const GpuProgramParametersPtr& params, uint16 variabilityMask);
+
         const String& getName(void) const;
 
-        RenderWindow* _initialise(bool autoCreateWindow, const String& windowTitle = "OGRE Render Window");
+        void _initialise() override;
 
         virtual RenderSystemCapabilities* createRenderSystemCapabilities() const;
 
@@ -183,8 +169,6 @@ namespace Ogre {
 
         void shutdown(void);
 
-        void setAmbientLight(float r, float g, float b);
-
         void setShadingType(ShadeOptions so);
 
         void setLightingEnabled(bool enabled);
@@ -199,10 +183,6 @@ namespace Ogre {
 
         /// @copydoc RenderSystem::_createDepthBufferFor
         DepthBuffer* _createDepthBufferFor( RenderTarget *renderTarget );
-
-        /// Mimics D3D9RenderSystem::_getDepthStencilFormatFor, if no FBO RTT manager, outputs GL_NONE
-        void _getDepthStencilFormatFor( PixelFormat internalColourFormat, GLenum *depthFormat,
-                                        GLenum *stencilFormat );
         
         /// @copydoc RenderSystem::createMultiRenderTarget
         virtual MultiRenderTarget * createMultiRenderTarget(const String & name); 
@@ -216,23 +196,17 @@ namespace Ogre {
         // Low-level overridden members
         // -----------------------------
 
-        void _useLights(const LightList& lights, unsigned short limit);
+        void _useLights(unsigned short limit);
 
-        bool areFixedFunctionLightsInViewSpace() const { return true; }
+        void setWorldMatrix(const Matrix4 &m);
 
-        void _setWorldMatrix(const Matrix4 &m);
+        void setViewMatrix(const Matrix4 &m);
 
-        void _setViewMatrix(const Matrix4 &m);
+        void setProjectionMatrix(const Matrix4 &m);
 
-        void _setProjectionMatrix(const Matrix4 &m);
+        void _setSurfaceTracking(TrackVertexColourType tracking);
 
-        void _setSurfaceParams(const ColourValue &ambient,
-            const ColourValue &diffuse, const ColourValue &specular,
-            const ColourValue &emissive, Real shininess,
-            TrackVertexColourType tracking);
-
-        void _setPointParameters(Real size, bool attenuationEnabled, 
-            Real constant, Real linear, Real quadratic, Real minSize, Real maxSize);
+        void _setPointParameters(bool attenuationEnabled, Real minSize, Real maxSize);
 
         void _setLineWidth(float width);
 
@@ -251,10 +225,6 @@ namespace Ogre {
 
         void _setTextureAddressingMode(size_t stage, const Sampler::UVWAddressingMode& uvw);
 
-        void _setTextureBorderColour(size_t stage, const ColourValue& colour);
-
-        void _setTextureMipmapBias(size_t unit, float bias);
-
         void _setTextureMatrix(size_t stage, const Matrix4& xform);
 
         void _setSeparateSceneBlending(SceneBlendFactor sourceFactor, SceneBlendFactor destFactor, SceneBlendFactor sourceFactorAlpha, SceneBlendFactor destFactorAlpha, SceneBlendOperation op, SceneBlendOperation alphaOp );
@@ -281,7 +251,7 @@ namespace Ogre {
 
         void _setColourBufferWriteEnabled(bool red, bool green, bool blue, bool alpha);
 
-        void _setFog(FogMode mode, const ColourValue& colour, Real density, Real start, Real end);
+        void _setFog(FogMode mode);
 
         void setClipPlane (ushort index, Real A, Real B, Real C, Real D);
 
@@ -303,12 +273,6 @@ namespace Ogre {
 
         void _setTextureUnitFiltering(size_t unit, FilterType ftype, FilterOptions filter);
 
-        void _setTextureUnitCompareFunction(size_t unit, CompareFunction function);
-
-        void _setTextureUnitCompareEnabled(size_t unit, bool compare);
-
-        void _setTextureLayerAnisotropy(size_t unit, unsigned int maxAnisotropy);
-
         void _render(const RenderOperation& op);
 
         void bindGpuProgram(GpuProgram* prg);
@@ -360,9 +324,6 @@ namespace Ogre {
 
         /// @copydoc RenderSystem::getDisplayMonitorCount
         unsigned int getDisplayMonitorCount() const;
-
-        /// @copydoc RenderSystem::hasAnisotropicMipMapFilter
-        virtual bool hasAnisotropicMipMapFilter() const { return false; }
         
         /// @copydoc RenderSystem::beginProfileEvent
         virtual void beginProfileEvent( const String &eventName );
